/*
 * SampleClient.java
 *
 * Copyright (c) 2002 CERN, on behalf of the EU DataGrid.
 * For license conditions see LICENSE file or
 * http://www.edg.org/license.html
 */

import java.net.URL;

import org.edg.security.voms.service.User;
import org.edg.security.voms.service.admin.VOMSAdmin;
import org.edg.security.voms.service.admin.VOMSAdminServiceLocator;

/**
 * A very simple client stub to show the usage of the Java API.
 *
 * @author <a href = "mailto:Akos.Frohner@cern.ch">kos Frohner</a>
 * @version $Id: SampleClient.java,v 1.2 2003/11/20 22:05:43 szamcsi Exp $
 */
public class SampleClient {
    /** We never create a new instance of SampleClient */
    private  SampleClient() {
    }
    
    
    public static void main(final String[] args) throws Exception {
        final String location = getLocation(args);
        final VOMSAdmin stub = makeStub(location);

        
        final User users[]= stub.listMembers(null);
        for(int i= 0; i < users.length; i++) {
            System.out.println("User: " + users[i].getDN());
        }
    }
    private static VOMSAdmin makeStub(final String location) throws Exception 
    {
        final VOMSAdminServiceLocator locator = new VOMSAdminServiceLocator();
	    if(location.length() == 0) {
	        System.out.println("Using default location: "
			       + locator.getVOMSAdminAddress());
	        return locator.getVOMSAdmin();
	    }
	    System.out.println("Connecting to: " + location);
	    return locator.getVOMSAdmin(new URL(location));
    }

    private static String getLocation(String[] args) {
	    final String prop = System.getProperty("edg-voms-admin.url", "").trim();
	    if(prop.length() != 0)
	        return prop;
	    if(args.length >= 1) 
	        return args[0];
	    return "";
    }
}

